=== modified file 'mandos-ctl'
--- mandos-ctl	2019-03-09 15:47:52 +0000
+++ mandos-ctl	2019-03-08 23:55:34 +0000
@@ -276,7 +276,7 @@
 # Abstract classes first
 class Command(object):
     """Abstract class for commands"""
-    def run(self, mandos, mandos_objmgr, clients):
+    def run(self, mandos, clients):
         """Normal commands should implement run_on_one_client(), but
         commands which want to operate on all clients at the same time
         can override this run() method instead."""
@@ -293,8 +293,8 @@
                     "LastApprovalRequest", "ApprovalDelay",
                     "ApprovalDuration", "Checker", "ExtendedTimeout",
                     "Expires", "LastCheckerStatus")
-    def run(self, mandos, mandos_objmgr, clients):
-        print(self.output(mandos_objmgr, clients.values()))
+    def run(self, mandos, clients):
+        print(self.output(clients))
 
 class PropertyCmd(Command):
     """Abstract class for Actions for setting one client property"""
@@ -331,12 +331,12 @@
     def __init__(self, verbose=False):
         self.verbose = verbose
 
-    def output(self, mandos_objmgr, clients):
+    def output(self, clients):
         default_keywords = ("Name", "Enabled", "Timeout", "LastCheckedOK")
         keywords = default_keywords
         if self.verbose:
             keywords = self.all_keywords
-        return str(self.TableOfClients(clients, keywords))
+        return str(self.TableOfClients(clients.values(), keywords))
 
     class TableOfClients(object):
         tableheaders = {
@@ -415,7 +415,7 @@
 
 
 class DumpJSONCmd(PrintCmd):
-    def output(self, mandos_objmgr, clients):
+    def output(self, clients):
         data = {client["Name"]:
                 {key: self.dbus_boolean_to_bool(client[key])
                  for key in self.all_keywords}
@@ -433,12 +433,7 @@
             sys.exit(0)
         sys.exit(1)
     def is_enabled(self, client, properties):
-        log.debug("D-Bus: %s:%s:%s.Get(%r, %r)", busname,
-                  client.__dbus_object_path__,
-                  dbus.PROPERTIES_IFACE, client_interface,
-                  "Enabled")
-        return bool(client.Get(client_interface, "Enabled",
-                               dbus_interface=dbus.PROPERTIES_IFACE))
+        return bool(properties["Enabled"])
 
 class RemoveCmd(Command):
     def run_on_one_client(self, client, properties):
@@ -616,6 +611,9 @@
     if options.is_enabled:
         commands.append(IsEnabledCmd())
 
+    if options.remove:
+        commands.append(RemoveCmd())
+
     if options.checker is not None:
         commands.append(SetCheckerCmd(options.checker))
 
@@ -654,9 +652,6 @@
     if options.deny:
         commands.append(DenyCmd())
 
-    if options.remove:
-        commands.append(RemoveCmd())
-
     # If no command option has been given, show table of clients,
     # optionally verbosely
     if not commands:
@@ -700,11 +695,6 @@
         parser.error("--all requires an action.")
     if options.is_enabled and len(options.client) > 1:
         parser.error("--is-enabled requires exactly one client")
-    if options.remove:
-        options.remove = False
-        if has_actions(options) and not options.deny:
-            parser.error("--remove can only be combined with --deny")
-        options.remove = True
 
 
 def main():
@@ -778,7 +768,7 @@
     # Run all commands on clients
     commands = commands_from_options(options)
     for command in commands:
-        command.run(mandos_serv, mandos_serv_object_manager, clients)
+        command.run(mandos_serv, clients)
 
 
 class Test_milliseconds_to_string(unittest.TestCase):
@@ -908,7 +898,7 @@
 
 class TestPrintTableCmd(TestCmd):
     def test_normal(self):
-        output = PrintTableCmd().output(None, self.clients.values())
+        output = PrintTableCmd().output(self.clients)
         expected_output = """
 Name   Enabled Timeout  Last Successful Check
 foo    Yes     00:05:00 2019-02-03T00:00:00  
@@ -916,8 +906,7 @@
 """[1:-1]
         self.assertEqual(output, expected_output)
     def test_verbose(self):
-        output = PrintTableCmd(verbose=True).output(
-            None, self.clients.values())
+        output = PrintTableCmd(verbose=True).output(self.clients)
         expected_output = """
 Name   Enabled Timeout  Last Successful Check Created             Interval Host            Key ID                                                           Fingerprint                              Check Is Running Last Enabled        Approval Is Pending Approved By Default Last Approval Request Approval Delay Approval Duration Checker              Extended Timeout Expires             Last Checker Status
 foo    Yes     00:05:00 2019-02-03T00:00:00   2019-01-02T00:00:00 00:02:00 foo.example.org 92ed150794387c03ce684574b1139a6594a34f895daaaf09fd8ea90a27cddb12 778827225BA7DE539C5A7CFA59CFF7CDBD9A5920 No               2019-01-03T00:00:00 No                  Yes                                       00:00:00       00:00:01          fping -q -- %(host)s 00:15:00         2019-02-04T00:00:00 0                  
@@ -925,7 +914,7 @@
 """[1:-1]
         self.assertEqual(output, expected_output)
     def test_one_client(self):
-        output = PrintTableCmd().output(None, self.one_client.values())
+        output = PrintTableCmd().output(self.one_client)
         expected_output = """
 Name Enabled Timeout  Last Successful Check
 foo  Yes     00:05:00 2019-02-03T00:00:00  
@@ -986,12 +975,11 @@
         }
         return super(TestDumpJSONCmd, self).setUp()
     def test_normal(self):
-        json_data = json.loads(DumpJSONCmd().output(None,
-                                                    self.clients))
+        json_data = json.loads(DumpJSONCmd().output(self.clients))
         self.assertDictEqual(json_data, self.expected_json)
     def test_one_client(self):
         clients = self.one_client
-        json_data = json.loads(DumpJSONCmd().output(None, clients))
+        json_data = json.loads(DumpJSONCmd().output(clients))
         expected_json = {"foo": self.expected_json["foo"]}
         self.assertDictEqual(json_data, expected_json)
 
@@ -1001,7 +989,7 @@
                             for client, properties in self.clients.items()))
     def test_is_enabled_run_exits_successfully(self):
         with self.assertRaises(SystemExit) as e:
-            IsEnabledCmd().run(None, None, self.one_client)
+            IsEnabledCmd().run(None, self.one_client)
         if e.exception.code is not None:
             self.assertEqual(e.exception.code, 0)
         else:
@@ -1009,7 +997,7 @@
     def test_is_enabled_run_exits_with_failure(self):
         self.client.attributes["Enabled"] = dbus.Boolean(False)
         with self.assertRaises(SystemExit) as e:
-            IsEnabledCmd().run(None, None, self.one_client)
+            IsEnabledCmd().run(None, self.one_client)
         if isinstance(e.exception.code, int):
             self.assertNotEqual(e.exception.code, 0)
         else:
@@ -1024,7 +1012,7 @@
                 self.calls.append(("RemoveClient", (dbus_path,)))
         mandos = MockMandos()
         super(TestRemoveCmd, self).setUp()
-        RemoveCmd().run(mandos, None, self.clients)
+        RemoveCmd().run(mandos, self.clients)
         self.assertEqual(len(mandos.calls), 2)
         for client in self.clients:
             self.assertIn(("RemoveClient",
@@ -1033,14 +1021,14 @@
 
 class TestApproveCmd(TestCmd):
     def test_approve(self):
-        ApproveCmd().run(None, None, self.clients)
+        ApproveCmd().run(None, self.clients)
         for client in self.clients:
             self.assertIn(("Approve", (True, client_interface)),
                           client.calls)
 
 class TestDenyCmd(TestCmd):
     def test_deny(self):
-        DenyCmd().run(None, None, self.clients)
+        DenyCmd().run(None, self.clients)
         for client in self.clients:
             self.assertIn(("Approve", (False, client_interface)),
                           client.calls)
@@ -1050,14 +1038,14 @@
         for client in self.clients:
             client.attributes["Enabled"] = False
 
-        EnableCmd().run(None, None, self.clients)
+        EnableCmd().run(None, self.clients)
 
         for client in self.clients:
             self.assertTrue(client.attributes["Enabled"])
 
 class TestDisableCmd(TestCmd):
     def test_disable(self):
-        DisableCmd().run(None, None, self.clients)
+        DisableCmd().run(None, self.clients)
 
         for client in self.clients:
             self.assertFalse(client.attributes["Enabled"])
@@ -1085,7 +1073,7 @@
                 self.assertNotIsInstance(value, Unique)
                 self.assertEqual(value, value_to_get)
     def run_command(self, value, clients):
-        self.command().run(None, None, clients)
+        self.command().run(None, clients)
 
 class TestBumpTimeoutCmd(TestPropertyCmd):
     command = BumpTimeoutCmd
@@ -1120,7 +1108,7 @@
             return
         return super(TestValueArgumentPropertyCmd, self).runTest()
     def run_command(self, value, clients):
-        self.command(value).run(None, None, clients)
+        self.command(value).run(None, clients)
 
 class TestSetCheckerCmd(TestValueArgumentPropertyCmd):
     command = SetCheckerCmd
@@ -1367,22 +1355,6 @@
     def test_is_enabled_short(self):
         self.assert_command_from_args(["-V", "foo"], IsEnabledCmd)
 
-    def test_deny_before_remove(self):
-        options = self.parser.parse_args(["--deny", "--remove", "foo"])
-        check_option_syntax(self.parser, options)
-        commands = commands_from_options(options)
-        self.assertEqual(len(commands), 2)
-        self.assertIsInstance(commands[0], DenyCmd)
-        self.assertIsInstance(commands[1], RemoveCmd)
-
-    def test_deny_before_remove_reversed(self):
-        options = self.parser.parse_args(["--remove", "--deny", "--all"])
-        check_option_syntax(self.parser, options)
-        commands = commands_from_options(options)
-        self.assertEqual(len(commands), 2)
-        self.assertIsInstance(commands[0], DenyCmd)
-        self.assertIsInstance(commands[1], RemoveCmd)
-
 
 class Test_check_option_syntax(unittest.TestCase):
     # This mostly corresponds to the definition from has_actions() in
@@ -1503,17 +1475,6 @@
         with self.assertParseError():
             self.check_option_syntax(options)
 
-    def test_remove_can_only_be_combined_with_action_deny(self):
-        for action, value in self.actions.items():
-            if action in {"remove", "deny"}:
-                continue
-            options = self.parser.parse_args()
-            setattr(options, action, value)
-            options.all = True
-            options.remove = True
-            with self.assertParseError():
-                self.check_option_syntax(options)
-
 
 
 def should_only_run_tests():

